@@ -30,22 +30,23 @@ TRANS_LOCAL = """#!/bin/bash
 
 {LISTP}
 
+{FOOTER}
 """
 ITEM = """
 echo "🍯 Compiling from {COMPILE_COIN} 🧀"
-SOLC_VERSION={SOLVER} solc --evm-version {EVMVERSION} --allow-paths {SOLCPATH} -o build --bin --bin-runtime --abi --optimize --metadata --overwrite {COMPILE_COIN}
+SOLC_VERSION={SOLVER} solc --evm-version {EVMVERSION} --allow-paths {SOLCPATH} -o build --bin --bin-runtime --abi --optimize-runs={RUNS} --metadata --overwrite {COMPILE_COIN}
 echo "=> 🍺🍺🍺 {COMPILE_COIN}"
 """
 
 ITEMLINK = """
 echo "🍰 Compiling with LINK from {COMPILE_COIN} 🧀"
 #solc --optimize --bin MetaCoin.sol | solc --link --libraries TestLib:<address>
-SOLC_VERSION={SOLVER} solc --allow-paths {SOLCPATH} -o build  --optimize --bin --abi --link --libraries "{FILES_CONFIG}" --overwrite {COMPILE_COIN}
+SOLC_VERSION={SOLVER} solc --allow-paths {SOLCPATH} -o build --optimize-runs={RUNS} --bin --abi --link --libraries "{FILES_CONFIG}" --overwrite {COMPILE_COIN}
 echo "=> 🍥🍥🍥 {COMPILE_COIN}"
 """
 
 ITEM_CP_LOCAL = """
-echo "==> 🚸 file system operation, move files.. 
+echo "==> 🚸 file system operation, move files.."
 rm "{tolocation}"
 cp "{fromlocation}" "{tolocation}"
 """
@@ -76,10 +77,12 @@ abi-gen-uni --abibins "{target_abi}" --out "{outputfolder}" \
 
 echo "==> generate abi to typescript --> 🧊"
 """
+
 ITEM_TRANSPILE_GO = """
+
 echo "==> 🚸 compile abi to golang"
-if [[ ! -f {outputfolder} ]]; then
-    mkdir -p {outputfolder}
+if [[ ! -f {outputfolder}/{classname} ]]; then
+    mkdir -p {outputfolder}/{classname}
 fi
 
 abigen --abi {target_abi} --pkg {classname} --type {classname} --out {outputfolder}/{classname}/init.go
@@ -89,6 +92,13 @@ echo "==> generate abi to golang --> 🧊"
 
 PRE_HEAD = """
 
+# . ./{path_definitions}
+
+if [[ ! -d factoryabi ]]; then
+  echo "The factory abi module is not found"
+  exit
+fi
+
 if ! command -v abi-gen-uni &>/dev/null; then
     echo "abi-gen-uni could not be found"
     cnpm i -g easy-abi-gen
@@ -99,3 +109,9 @@ if ! command -v abigen &>/dev/null; then
     exit;
 fi
 """
+SUB_FOOTER= """
+
+#rm localpile
+#rm -rf factoryabi
+
+"""
\ No newline at end of file
